﻿-- Author      : Deldinor of Elune
-- Create Date : 2/1/2011 7:31:49 AM

DailyGrind = LibStub("AceAddon-3.0"):NewAddon("DailyGrind", "AceConsole-3.0", "AceEvent-3.0")

local titleColor = "FFCCCCCC";
local titleText = "|c"..titleColor.."Daily Grind|r";
local commandColor = "FFFFC654";
local disabledText = "|cFFFF0000DISABLED|r";
local enabledText = "|cFF00FF00ENABLED|r";

function DailyGrind:OnInitialize()   
    self:RegisterChatCommand("dailygrind", "ChatCommand");
    self:RegisterChatCommand("dg", "ChatCommand"); 
    if DailyGrindQuests == nil then
		DailyGrindQuests = {};
    end
    if DailyGrindSettings == nil then
		DailyGrindSettings = { Enabled = true; };
    end
end
	
function DailyGrind:OnEnable()
    self:RegisterEvent("GOSSIP_SHOW");
    self:RegisterEvent("QUEST_DETAIL");
    self:RegisterEvent("QUEST_PROGRESS");
    self:RegisterEvent("QUEST_COMPLETE");
end

function DailyGrind:ChatCommand(input)
	if input:trim() == "import" then
		-- TODO: Implement confirmation.
        for index, value in pairs(KnownDailies) do
			DailyGrindQuests[index] = value;
        end
		DEFAULT_CHAT_FRAME:AddMessage("All known "..titleText.." quests imported.");
	elseif input:trim() == "reset" then
		-- TODO: Implement confirmation.
		DailyGrindQuests = {};
		DEFAULT_CHAT_FRAME:AddMessage(titleText.." quest history reset.");
	elseif input:trim() == "enable" then
		DailyGrindSettings.Enabled = true;
		DEFAULT_CHAT_FRAME:AddMessage(self:GetStatus());
	elseif input:trim() == "disable" then
		DailyGrindSettings.Enabled = false;
		DEFAULT_CHAT_FRAME:AddMessage(self:GetStatus());
	elseif input:trim() == "toggle" then
		DailyGrindSettings.Enabled = not DailyGrindSettings.Enabled;
		DEFAULT_CHAT_FRAME:AddMessage(self:GetStatus());
	else
		self:ShowHelp();
    end
end

function DailyGrind:GetStatus()
	if DailyGrindSettings.Enabled then
		return titleText.." : "..enabledText;
	else
		return titleText.." : "..disabledText;
	end
end

function DailyGrind:ShowHelp()
	local state = disabledText;
	if DailyGrindSettings.Enabled then
		state = enabledText;
	end
	DEFAULT_CHAT_FRAME:AddMessage("\n==  "..self:GetStatus().."  ==");
	DEFAULT_CHAT_FRAME:AddMessage("All dailies that you complete will be added to a database. Whenever you see that daily again, you will auto-accept/complete it.");
	DEFAULT_CHAT_FRAME:AddMessage("A list of currently-known dailies is included; you may import this list into your database using |c"..commandColor.."/dg import|r.");
	DEFAULT_CHAT_FRAME:AddMessage("Currently, if there is a choice of reward available, you must choose a reward manually. This will be addressed in a future update.");
	DEFAULT_CHAT_FRAME:AddMessage("Usage:  |c"..commandColor.."/dg <enable> <disable> <toggle> <import> <reset>|r");
end

function DailyGrind:GOSSIP_SHOW()
	if not DailyGrindSettings.Enabled then
		return;
	end

	-- Turn in known completed quests.
	local numActiveQuests = GetNumGossipActiveQuests();
	if numActiveQuests > 0 then
		local activeQuests = {GetGossipActiveQuests()};
		for i = 1, numActiveQuests, 1 do
			local nameIdx = (4 * (i - 1)) + 1;
			local isDailyIdx = nameIdx + 3;
			if activeQuests[isDailyIdx] and DailyGrindQuests[activeQuests[nameIdx]] then
				SelectGossipActiveQuest(i);
			end
		end
	end
	
	-- Accept known available quests.
	local numAvailableQuests = GetNumGossipAvailableQuests();
	if numAvailableQuests > 0 then
		local availableQuests = {GetGossipAvailableQuests()};
		for i = 1, numAvailableQuests, 1 do
			local nameIdx = (5 * (i - 1)) + 1;
			if DailyGrindQuests[availableQuests[nameIdx]] then
				SelectGossipAvailableQuest(i);
			end
		end
	end
	
end

function DailyGrind:QUEST_DETAIL()
	if not DailyGrindSettings.Enabled then
		return;
	end
	
	if DailyGrindQuests[GetTitleText()] then
		AcceptQuest();
	end
end

function DailyGrind:QUEST_PROGRESS()
	if not DailyGrindSettings.Enabled then
		return;
	end
	
	if IsQuestCompletable() and DailyGrindQuests[GetTitleText()] then
		CompleteQuest();
	end
end

function DailyGrind:QUEST_COMPLETE()
	if not DailyGrindSettings.Enabled then
		return;
	end
	
	if DailyGrindQuests[GetTitleText()] then
		if GetNumQuestChoices() == 0 then
			GetQuestReward(0)
		end	-- TODO: Implement auto-rewards list
	elseif (QuestIsDaily() or QuestIsWeekly()) then
		DailyGrindQuests[GetTitleText()] = 1;
	end
end